==> pysatNASA-0.0.2.tar.gz: pysatNASA-0.0.2/pysatNASA/instruments/methods/gold.py <==
# -*- coding: utf-8 -*-
"""Provides non-instrument specific routines for GOLD data"""

ack_str = ' '.join(('This is a data product from the NASA Global-scale',
                    'Observations of the Limb and Disk (GOLD) mission, an',
                    'Heliophysics Explorer mission of opportunity launched',
                    'in January 2018.\n Responsibility of the mission',
                    'science falls to the Principal Investigator, Dr.',
                    'Richard Eastes at University of Colorado/LASP.\n',
                    'Validation of the L1B data products falls to the',
                    'instrument lead investigators/scientists.\n* EUV',
                    'Dr. Bill McClintock\nValidation of the L2 data',
                    'products falls to Computational Physics, Inc.\n* Dr.',
                    'Jerry Lumpe\n (https://gold.cs.ucf.edu/).\nOverall',
                    'validation of the products is overseen by the GOLD',
                    'Project Scientist Dr. Alan Burns.\nUsers of these',
                    'data should contact and acknowledge the Principal',
                    'Investigator Dr. Richard Eastes and the party',
                    'directly responsible for the data product and the',
                    'NASA Explorers Project Office.'))
ref_str = ' '.join(('Eastes, R.W., McClintock, W.E., Burns, A.G. et al.',
                    'The Global-Scale Observations of the Limb and Disk',
                    '(GOLD) Mission. Space Sci Rev 212, 383–408 (2017).',
                    'https://doi.org/10.1007/s11214-017-0392-2'))

==> pysatNASA-0.0.3.tar.gz: pysatNASA-0.0.3/pysatNASA/instruments/methods/gold.py <==
# -*- coding: utf-8 -*-
"""Provides non-instrument specific routines for GOLD data."""

ack_str = ' '.join(('This is a data product from the NASA Global-scale',
                    'Observations of the Limb and Disk (GOLD) mission, an',
                    'Heliophysics Explorer mission of opportunity launched',
                    'in January 2018.\n Responsibility of the mission',
                    'science falls to the Principal Investigator, Dr.',
                    'Richard Eastes at University of Colorado/LASP.\n',
                    'Validation of the L1B data products falls to the',
                    'instrument lead investigators/scientists.\n* EUV',
                    'Dr. Bill McClintock\nValidation of the L2 data',
                    'products falls to Computational Physics, Inc.\n* Dr.',
                    'Jerry Lumpe\n (https://gold.cs.ucf.edu/).\nOverall',
                    'validation of the products is overseen by the GOLD',
                    'Project Scientist Dr. Alan Burns.\nUsers of these',
                    'data should contact and acknowledge the Principal',
                    'Investigator Dr. Richard Eastes and the party',
                    'directly responsible for the data product and the',
                    'NASA Explorers Project Office.'))
ref_str = ' '.join(('Eastes, R.W., McClintock, W.E., Burns, A.G. et al.',
                    'The Global-Scale Observations of the Limb and Disk',
                    '(GOLD) Mission. Space Sci Rev 212, 383–408 (2017).',
                    'https://doi.org/10.1007/s11214-017-0392-2'))
